@@ -20,7 +20,7 @@ typedef Eo Elm_Naviframe_Part;
  */
 #define ELM_NAVIFRAME_PART_CLASS elm_naviframe_part_class_get()
 
-EWAPI const Efl_Class *elm_naviframe_part_class_get(void) EINA_CONST;
+EAPI EAPI_WEAK const Efl_Class *elm_naviframe_part_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
